pub struct LimitsConfiguration {Show 20 fields
pub max_envelope_bytes: u64,
pub max_request_bytes: u64,
pub max_response_bytes: u64,
pub max_publish_topics: u32,
pub max_query_topics: u32,
pub max_query_limit: u32,
pub default_query_limit: u32,
pub max_newest_metadata_topics: u32,
pub max_newest_full_topics: u32,
pub max_update_adds: u32,
pub max_update_removes: u32,
pub max_stream_topics: u32,
pub max_static_topics: u32,
pub max_lookup_identifiers: u32,
pub max_scw_signatures: u32,
pub max_identity_entries: u32,
pub max_update_frames_per_second: u32,
pub max_update_burst: u32,
pub max_ping_frames_per_second: u32,
pub max_ping_burst: u32,
}Expand description
Request shapes the backend accepts. A client chunks its work to these values.
Fields
max_envelope_bytes: u64max_request_bytes: u64max_response_bytes: u64max_publish_topics: u32max_query_topics: u32max_query_limit: u32default_query_limit: u32max_newest_metadata_topics: u32max_newest_full_topics: u32max_update_adds: u32max_update_removes: u32max_stream_topics: u32max_static_topics: u32max_lookup_identifiers: u32max_scw_signatures: u32max_identity_entries: u32max_update_frames_per_second: u32max_update_burst: u32max_ping_frames_per_second: u32max_ping_burst: u32Trait Implementations
Sourceimpl Clone for LimitsConfiguration
impl Clone for LimitsConfiguration
Sourcefn clone(&self) -> LimitsConfiguration
fn clone(&self) -> LimitsConfiguration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LimitsConfiguration
impl Debug for LimitsConfiguration
Sourceimpl Default for LimitsConfiguration
impl Default for LimitsConfiguration
Sourceimpl<'de> Deserialize<'de> for LimitsConfiguration
impl<'de> Deserialize<'de> for LimitsConfiguration
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<LimitsConfiguration> for LimitsConfiguration
impl From<LimitsConfiguration> for LimitsConfiguration
Sourcefn from(limits: LimitsConfiguration) -> Self
fn from(limits: LimitsConfiguration) -> Self
Converts to this type from the input type.
Sourceimpl Hash for LimitsConfiguration
impl Hash for LimitsConfiguration
Sourceimpl Message for LimitsConfiguration
impl Message for LimitsConfiguration
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for LimitsConfiguration
impl Name for LimitsConfiguration
Sourceconst NAME: &'static str = "LimitsConfiguration"
const NAME: &'static str = "LimitsConfiguration"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "xmtp.backend.v1"
const PACKAGE: &'static str = "xmtp.backend.v1"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for LimitsConfiguration
impl PartialEq for LimitsConfiguration
Sourcefn eq(&self, other: &LimitsConfiguration) -> bool
fn eq(&self, other: &LimitsConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LimitsConfiguration
impl Serialize for LimitsConfiguration
impl Copy for LimitsConfiguration
impl Eq for LimitsConfiguration
impl StructuralPartialEq for LimitsConfiguration