pub struct AddMissingInstallations {
pub group_id: Vec<u8>,
}Expand description
Durable TaskRunner intent: reconcile a group’s membership with the inbox’s latest identity state (add installations registered after the group was last updated). Enqueued by the device-sync worker when a sync-group welcome signals a new installation; runs on the TaskRunner with retry/backoff so a transient failure (e.g. identity propagation lag) cannot permanently skip the add. group_id is the target conversation.
Fields
group_id: Vec<u8>Trait Implementations
Sourceimpl Clone for AddMissingInstallations
impl Clone for AddMissingInstallations
Sourcefn clone(&self) -> AddMissingInstallations
fn clone(&self) -> AddMissingInstallations
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddMissingInstallations
impl Debug for AddMissingInstallations
Sourceimpl Default for AddMissingInstallations
impl Default for AddMissingInstallations
Sourceimpl<'de> Deserialize<'de> for AddMissingInstallations
impl<'de> Deserialize<'de> for AddMissingInstallations
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AddMissingInstallations
impl Hash for AddMissingInstallations
Sourceimpl Message for AddMissingInstallations
impl Message for AddMissingInstallations
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for AddMissingInstallations
impl Name for AddMissingInstallations
Sourceconst NAME: &'static str = "AddMissingInstallations"
const NAME: &'static str = "AddMissingInstallations"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "xmtp.mls.database"
const PACKAGE: &'static str = "xmtp.mls.database"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for AddMissingInstallations
impl PartialEq for AddMissingInstallations
Sourcefn eq(&self, other: &AddMissingInstallations) -> bool
fn eq(&self, other: &AddMissingInstallations) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AddMissingInstallations
impl Serialize for AddMissingInstallations
impl Eq for AddMissingInstallations
impl StructuralPartialEq for AddMissingInstallations