#[repr(i32)]pub enum ConversationType {
Unspecified = 0,
Group = 1,
Dm = 2,
Sync = 3,
Oneshot = 4,
}Expand description
Defines the type of conversation
Variants
Implementations
Sourceimpl ConversationType
impl ConversationType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ConversationType.
Sourcepub fn from_i32(value: i32) -> Option<ConversationType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ConversationType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ConversationType, or None if value is not a valid variant.
Sourceimpl ConversationType
impl ConversationType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.